# Клондайк аналитика

![analyst-klondike-splash](https://клондайк-аналитика.рф/static/images/python_coach_app_page/app_main_screenshot_min.png)

Клондайк-аналитика - интерактивный тренажер Python в вашем компьютере. Решайте задачи, запускайте код, получайте немедленную обратную связь.

## Всем привет!

Вас приветствует **Клондайк аналитика**, интерактивный тренажер Python на вашем компьютере.

Чтобы ознакомиться с возможностями программы, пройдите **демо-тест**.

## Как решать задачи на тренажере:
-  Скачать файл с задачами на компьютер
-  Перейти в каталог, где находится загруженный файл, набрав команду в терминале:

```
cd ~/path/to/my/downloaded_file
```

Можно убедиться, что файл действительно есть в каталоге, набрав команду ```ls```:

- Запустить программу, указав файл с задачами. Команда:

```
analyst_klodike my_tasks.json
```

- Допускается запуск тренажера без указания файла. Для этого напишите в терминале:

```
analyst_klodike
```

После запуска программы нажмите кнопку **Открыть тест**, чтобы выбрать файл с задачами.

Успехов!

## Условия использования
Данная программа - коммерческий продукт. **Никакая** ее часть не может быть использована без разрешения автора. Исходный код программы является закрытым. Никая часть исходного кода не может быть использована без разрешения автора. Исключительные права на эту программу принадлежат Малюге Илье Викторовичу (info@клондайк-аналитика.рф).